@@ -6,7 +6,7 @@ use Carp;
 use POE::Component::IRC::Plugin qw( :ALL );
 use POE::Component::IRC::Common qw( u_irc );
 
-our $VERSION = '6.18';
+our $VERSION = '6.20';
 
 sub new {
     my ($package) = shift;
@@ -32,12 +32,8 @@ sub S_004 {
     my ($self, $irc) = splice @_, 0, 2;
     my $version = ${ $_[2] }->[1];
 
-    if ($version =~ /ratbox/i) {
-        $irc->yield(quote => "NS IDENTIFY $self->{Password}");
-    }
-    else {
-        $irc->yield(nickserv => "IDENTIFY $self->{Password}");
-    }
+    $self->{ratbox} = $version =~ /ratbox/i ? 1 : 0;
+    $self->_identify();
     return PCI_EAT_NONE;
 }
 
@@ -47,11 +43,24 @@ sub S_nick {
     my $new_nick = u_irc( ${ $_[1] }, $mapping );
 
     if ( $new_nick eq u_irc($self->{nick}, $mapping) ) {
-        $irc->yield(nickserv => "IDENTIFY $self->{Password}");
+        $self->_identify();
     }
     return PCI_EAT_NONE;
 }
 
+sub _identify {
+    my ($self) = @_;
+    my $irc = $self->{irc};
+
+    if ($self->{ratbox}) {
+        $irc->yield(quote => "NS IDENTIFY $self->{Password}");
+    }
+    else {
+        $irc->yield(nickserv => "IDENTIFY $self->{Password}");
+    }
+    return;
+}
+
 1;
 __END__
 
